@@ -33,7 +33,11 @@ public:
     explicit KAccessApp();
     void newInstance();
     void setXkbOpcode(int opcode);
-    bool nativeEventFilter(const QByteArray &eventType, void *message, long int *result) override;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    bool nativeEventFilter(const QByteArray &eventType, void *message, long *result) override;
+#else
+    bool nativeEventFilter(const QByteArray &eventType, void *message, qintptr *result) override;
+#endif
 
     bool isFailed() const
     {
